@@ -1,6 +1,6 @@
 /* pmpz_arith -- mpz arithmetic functions
  *
- * Copyright (C) 2011 Daniele Varrazzo
+ * Copyright (C) 2011-2020 Daniele Varrazzo
  *
  * This file is part of the PostgreSQL GMP Module
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with the PostgreSQL GMP Module.  If not, see
- * http://www.gnu.org/licenses/.
+ * https://www.gnu.org/licenses/.
  */
 
 #include "pmpz.h"
@@ -28,6 +28,9 @@
 #if PG_VERSION_NUM >= 90300
 #include <access/htup_details.h>    /* for heap_form_tuple */
 #endif
+#if PG_VERSION_NUM >= 100000
+#include <utils/fmgrprotos.h>       /* for hashint8 */
+#endif
 
 
 /*
